<?php $TRANSLATIONS = array(
"Music" => "Muziko",
"Add album to playlist" => "Aldoni albumon al ludlisto",
"Play" => "Ludi",
"Pause" => "Paŭzigi",
"Previous" => "Maljena",
"Next" => "Jena",
"Mute" => "Silentigi",
"Unmute" => "Malsilentigi",
"Rescan Collection" => "Reskani la aron",
"Artist" => "Artisto",
"Album" => "Albumo",
"Title" => "Titolo"
);
